#ifndef BB_CLIENT_H
#define BB_CLIENT_H

// For demo purposes only
// Thin api for communicating with the 'bb_server' application
// Supports only one connection to the server
// Does not perform extensive error handling on connectivity status

#if defined(_WIN32)
  #ifdef BB_EXPORTS
    #define BBC_API __declspec(dllexport)
  #else
    #define BBC_API __declspec(dllimport)
  #endif
#endif

// These must match between server/client
struct bb_settings {
    double center;
    double span;
    double ref_level;
    double rbw;
    double vbw;
    double sweep_time;
    int spur_reject;
    int detector;
};

struct bb_sweep_info {
    double start_freq;
    double bin_size;
    int length;
};

enum bbcStatus {
    bbcConnectionErr,
    bbcNoConnectionErr,
    bbcConnectionAlreadyExistsErr,
    bbcSocketStartupErr,
    bbcInvalidConfigurationErr,
    bbcUnableToConnectErr,
    bbcNullPtrErr,
    bbcNoError,
    bbcIFOverload
};

#ifdef __cplusplus
extern "C" {
#endif

// Establish a connection to a listening server
BBC_API bbcStatus bbcConnect(const char *address);
// Abolish an active connection
BBC_API bbcStatus bbcDisconnect();

// Configure the device, if successful return sweep info
BBC_API bbcStatus bbcConfigure(const bb_settings *settings, bb_sweep_info *sweep_info);
// Get one sweep, must configure once before a sweep attempt is made
BBC_API bbcStatus bbcGetSweep(double *min, double *max);
// Preset the device, blocking call for potentially many seconds, does not
//  return until the remote device presets or fails to do so, if the device
//  fails to preset, the remote connection is closed, if the device sucessfully
//  presets, the same settings are used to reconfigure the device
BBC_API bbcStatus bbcPreset();

#ifdef __cplusplus
} // extern "C" 
#endif

#endif // BB_CLIENT_H